[Scummvm-cvs-logs] scummvm master -> 35577ab71e8482ce629decb220b7df0cf0482d0f

bluegr bluegr at gmail.com
Mon Nov 3 10:44:16 CET 2014


This automated email contains information about 5 new commits which have been
pushed to the 'scummvm' repo located at https://github.com/scummvm/scummvm .

Summary:
f733498388 GROOVIE: Finish implementation of o_hotspot_outrect
9d6437c01e GROOVIE: Add initial full screen functionality for V2 games
a82740516c GROOVIE: Implement o2_copyscreentobg and o2_copybgtoscreen
5dc03107fd GROOVIE: Add a stub for opcode 42 in V2 games
35577ab71e GROOVIE: Initial implementation of direct game load for the 11th Hour


Commit: f733498388267e1fb848eb758a2625c157a84857
    https://github.com/scummvm/scummvm/commit/f733498388267e1fb848eb758a2625c157a84857
Author: Filippos Karapetis (bluegr at gmail.com)
Date: 2014-11-03T11:40:36+02:00

Commit Message:
GROOVIE: Finish implementation of o_hotspot_outrect

This is needed by the main menu in the 11th Hour

Changed paths:
    engines/groovie/script.cpp



diff --git a/engines/groovie/script.cpp b/engines/groovie/script.cpp
index 7625151..4f4e45d 100644
--- a/engines/groovie/script.cpp
+++ b/engines/groovie/script.cpp
@@ -1595,8 +1595,7 @@ void Script::o_hotspot_outrect() {
 	bool contained = rect.contains(mousepos);
 
 	if (!contained) {
-		error("hotspot-outrect unimplemented");
-		// TODO: what to do with address?
+		_currentInstruction = address;
 	}
 }
 


Commit: 9d6437c01ef4e476fce47d37f4e879b39e830857
    https://github.com/scummvm/scummvm/commit/9d6437c01ef4e476fce47d37f4e879b39e830857
Author: Filippos Karapetis (bluegr at gmail.com)
Date: 2014-11-03T11:40:37+02:00

Commit Message:
GROOVIE: Add initial full screen functionality for V2 games

Changed paths:
    engines/groovie/graphics.cpp
    engines/groovie/graphics.h
    engines/groovie/roq.cpp
    engines/groovie/script.cpp



diff --git a/engines/groovie/graphics.cpp b/engines/groovie/graphics.cpp
index b85277f..e0c198f 100644
--- a/engines/groovie/graphics.cpp
+++ b/engines/groovie/graphics.cpp
@@ -63,7 +63,7 @@ void GraphicsMan::update() {
 
 			// Clear the buffer when ending the fade out
 			if (_fading == 2)
-				_foreground.fillRect(Common::Rect(640, 320), 0);
+				_foreground.fillRect(Common::Rect(640, _foreground.h), 0);
 		}
 	}
 
@@ -74,6 +74,22 @@ void GraphicsMan::update() {
 	}
 }
 
+void GraphicsMan::switchToFullScreen(bool fullScreen) {
+	_foreground.free();
+	_background.free();
+
+	if (fullScreen) {
+		_foreground.create(640, 480, _vm->_pixelFormat);
+		_background.create(640, 480, _vm->_pixelFormat);
+	} else {
+		_vm->_system->fillScreen(0);
+		_foreground.create(640, 320, _vm->_pixelFormat);
+		_background.create(640, 320, _vm->_pixelFormat);
+	}
+
+	_changed = true;
+}
+
 void GraphicsMan::change() {
 	_changed = true;
 }
@@ -84,7 +100,7 @@ void GraphicsMan::mergeFgAndBg() {
 
 	countf = (byte *)_foreground.getPixels();
 	countb = (byte *)_background.getPixels();
-	for (i = 640 * 320; i; i--) {
+	for (i = 640 * _foreground.h; i; i--) {
 		if (255 == *(countf)) {
 			*(countf) = *(countb);
 		}
@@ -94,7 +110,10 @@ void GraphicsMan::mergeFgAndBg() {
 }
 
 void GraphicsMan::updateScreen(Graphics::Surface *source) {
-	_vm->_system->copyRectToScreen(source->getPixels(), 640, 0, 80, 640, 320);
+	if (!isFullScreen())
+		_vm->_system->copyRectToScreen(source->getPixels(), source->pitch, 0, 80, 640, 320);
+	else
+		_vm->_system->copyRectToScreen(source->getPixels(), source->pitch, 0, 0, 640, 480);
 	change();
 }
 
diff --git a/engines/groovie/graphics.h b/engines/groovie/graphics.h
index 72ab01d..69934f9 100644
--- a/engines/groovie/graphics.h
+++ b/engines/groovie/graphics.h
@@ -38,6 +38,8 @@ public:
 	void update();
 	void change();
 	void mergeFgAndBg();
+	void switchToFullScreen(bool fullScreen);
+	bool isFullScreen() { return (_foreground.h == 480); }
 	void updateScreen(Graphics::Surface *source);
 	Graphics::Surface _foreground;	// The main surface that most things are drawn to
 	Graphics::Surface _background;	// Used occasionally, mostly (only?) in puzzles
diff --git a/engines/groovie/roq.cpp b/engines/groovie/roq.cpp
index 379fcab..0c73596 100644
--- a/engines/groovie/roq.cpp
+++ b/engines/groovie/roq.cpp
@@ -277,6 +277,12 @@ bool ROQPlayer::processBlockInfo(ROQBlockHeader &blockHeader) {
 		_prevBuf->create(width, height, _vm->_pixelFormat);
 	}
 
+	// Switch from/to fullscreen, if needed
+	if (_bg->h != 480 && height == 480)
+		_vm->_graphicsMan->switchToFullScreen(true);
+	else if (_bg->h == 480 && height != 480)
+		_vm->_graphicsMan->switchToFullScreen(false);
+
 	// Clear the buffers with black
 	_currBuf->fillRect(Common::Rect(width, height), _vm->_pixelFormat.RGBToColor(0, 0, 0));
 	_prevBuf->fillRect(Common::Rect(width, height), _vm->_pixelFormat.RGBToColor(0, 0, 0));
diff --git a/engines/groovie/script.cpp b/engines/groovie/script.cpp
index 4f4e45d..1d4ad0a 100644
--- a/engines/groovie/script.cpp
+++ b/engines/groovie/script.cpp
@@ -350,9 +350,10 @@ bool Script::hotspot(Common::Rect rect, uint16 address, uint8 cursor) {
 
 	// Show hotspots when debugging
 	if (DebugMan.isDebugChannelEnabled(kDebugHotspots)) {
-		rect.translate(0, -80);
+		if (!_vm->_graphicsMan->isFullScreen())
+			rect.translate(0, -80);
 		_vm->_graphicsMan->_foreground.frameRect(rect, 250);
-		_vm->_system->copyRectToScreen(_vm->_graphicsMan->_foreground.getPixels(), _vm->_graphicsMan->_foreground.pitch, 0, 80, 640, 320);
+		_vm->_graphicsMan->updateScreen(&_vm->_graphicsMan->_foreground);
 		_vm->_system->updateScreen();
 	}
 
@@ -962,7 +963,7 @@ void Script::o_strcmpnejmp_var() {			// 0x21
 
 void Script::o_copybgtofg() {			// 0x22
 	debugC(1, kDebugScript, "COPY_BG_TO_FG");
-	memcpy(_vm->_graphicsMan->_foreground.getPixels(), _vm->_graphicsMan->_background.getPixels(), 640 * 320);
+	memcpy(_vm->_graphicsMan->_foreground.getPixels(), _vm->_graphicsMan->_background.getPixels(), 640 * _vm->_graphicsMan->_foreground.h);
 }
 
 void Script::o_strcmpeqjmp() {			// 0x23
@@ -1198,6 +1199,7 @@ void Script::o_copyrecttobg() {	// 0x37
 	uint16 top = readScript16bits();
 	uint16 right = readScript16bits();
 	uint16 bottom = readScript16bits();
+	uint16 baseTop = (!_vm->_graphicsMan->isFullScreen()) ? 80 : 0;
 
 	// Sanity checks to prevent bad pointer access crashes
 	if (left > right) {
@@ -1216,9 +1218,9 @@ void Script::o_copyrecttobg() {	// 0x37
 		bottom = top;
 		top = j;
 	}
-	if (top < 80) {
-		warning("COPYRECT top < 80... clamping");
-		top = 80;
+	if (top < baseTop) {
+		warning("COPYRECT top < baseTop... clamping");
+		top = baseTop;
 	}
 	if (top >= 480) {
 		warning("COPYRECT top >= 480... clamping");
@@ -1243,13 +1245,13 @@ void Script::o_copyrecttobg() {	// 0x37
 
 	debugC(1, kDebugScript, "COPYRECT((%d,%d)->(%d,%d))", left, top, right, bottom);
 
-	fg = (byte *)_vm->_graphicsMan->_foreground.getBasePtr(left, top - 80);
-	bg = (byte *)_vm->_graphicsMan->_background.getBasePtr(left, top - 80);
+	fg = (byte *)_vm->_graphicsMan->_foreground.getBasePtr(left, top - baseTop);
+	bg = (byte *)_vm->_graphicsMan->_background.getBasePtr(left, top - baseTop);
 	for (i = 0; i < height; i++) {
 		memcpy(bg + offset, fg + offset, width);
 		offset += 640;
 	}
-	_vm->_system->copyRectToScreen(_vm->_graphicsMan->_background.getBasePtr(left, top - 80), 640, left, top, width, height);
+	_vm->_system->copyRectToScreen(_vm->_graphicsMan->_background.getBasePtr(left, top - baseTop), 640, left, top, width, height);
 	_vm->_graphicsMan->change();
 }
 


Commit: a82740516c9f973d8beaf1b11dd2f0a8a6beff5e
    https://github.com/scummvm/scummvm/commit/a82740516c9f973d8beaf1b11dd2f0a8a6beff5e
Author: Filippos Karapetis (bluegr at gmail.com)
Date: 2014-11-03T11:40:38+02:00

Commit Message:
GROOVIE: Implement o2_copyscreentobg and o2_copybgtoscreen

Changed paths:
    engines/groovie/script.cpp



diff --git a/engines/groovie/script.cpp b/engines/groovie/script.cpp
index 1d4ad0a..479ede5 100644
--- a/engines/groovie/script.cpp
+++ b/engines/groovie/script.cpp
@@ -1671,15 +1671,29 @@ void Script::o2_vdxtransition() {
 void Script::o2_copyscreentobg() {
 	uint16 val = readScript16bits();
 
+	// TODO: Parameter
+	if (val)
+		warning("o2_copyscreentobg: Param is %d", val);
+	
+	Graphics::Surface *screen = _vm->_system->lockScreen();
+	_vm->_graphicsMan->_background.copyFrom(screen->getSubArea(Common::Rect(0, 80, 640, 320)));
+	_vm->_system->unlockScreen();
+
 	debugC(1, kDebugScript, "CopyScreenToBG3: 0x%04X", val);
-	error("Unimplemented Opcode 0x4F");
 }
 
 void Script::o2_copybgtoscreen() {
 	uint16 val = readScript16bits();
 
+	// TODO: Parameter
+	if (val)
+		warning("o2_copybgtoscreen: Param is %d", val);
+
+	Graphics::Surface *screen = _vm->_system->lockScreen();
+	_vm->_graphicsMan->_background.copyRectToSurface(*screen, 0, 80, Common::Rect(0, 0, 640, 320 - 80));
+	_vm->_system->unlockScreen();
+
 	debugC(1, kDebugScript, "CopyBG3ToScreen: 0x%04X", val);
-	error("Unimplemented Opcode 0x50");
 }
 
 void Script::o2_setvideoskip() {


Commit: 5dc03107fd86abb725eff6d9ea704267534d9dfe
    https://github.com/scummvm/scummvm/commit/5dc03107fd86abb725eff6d9ea704267534d9dfe
Author: Filippos Karapetis (bluegr at gmail.com)
Date: 2014-11-03T11:40:38+02:00

Commit Message:
GROOVIE: Add a stub for opcode 42 in V2 games

This was o_cellmove in T7G (the Microscope puzzle)

Changed paths:
    engines/groovie/script.cpp
    engines/groovie/script.h



diff --git a/engines/groovie/script.cpp b/engines/groovie/script.cpp
index 479ede5..c4091f6 100644
--- a/engines/groovie/script.cpp
+++ b/engines/groovie/script.cpp
@@ -1701,6 +1701,12 @@ void Script::o2_setvideoskip() {
 	debugC(1, kDebugScript, "SetVideoSkip (0x%04X)", _videoSkipAddress);
 }
 
+void Script::o2_stub42() {
+	uint8 arg = readScript8bits();
+	// TODO: Switch with 5 cases (0 - 5). Anything above 5 is a NOP
+	debugC(1, kDebugScript, "STUB42 (0x%02X)", arg);
+}
+
 void Script::o2_stub52() {
 	uint8 arg = readScript8bits();
 	debugC(1, kDebugScript, "STUB52 (0x%02X)", arg);
@@ -1874,7 +1880,7 @@ Script::OpcodeFunc Script::_opcodesV2[NUM_OPCODES] = {
 	&Script::o_loadscript,
 	&Script::o_setvideoorigin, // 0x40
 	&Script::o_sub,
-	&Script::o_cellmove,
+	&Script::o2_stub42,
 	&Script::o_returnscript,
 	&Script::o_sethotspotright, // 0x44
 	&Script::o_sethotspotleft,
diff --git a/engines/groovie/script.h b/engines/groovie/script.h
index 35e5259..a9f6143 100644
--- a/engines/groovie/script.h
+++ b/engines/groovie/script.h
@@ -238,6 +238,7 @@ private:
 	void o2_setvideoskip();
 	void o2_copyscreentobg();
 	void o2_copybgtoscreen();
+	void o2_stub42();
 	void o2_stub52();
 	void o2_setscriptend();
 };


Commit: 35577ab71e8482ce629decb220b7df0cf0482d0f
    https://github.com/scummvm/scummvm/commit/35577ab71e8482ce629decb220b7df0cf0482d0f
Author: Filippos Karapetis (bluegr at gmail.com)
Date: 2014-11-03T11:40:38+02:00

Commit Message:
GROOVIE: Initial implementation of direct game load for the 11th Hour

Changed paths:
    engines/groovie/script.cpp



diff --git a/engines/groovie/script.cpp b/engines/groovie/script.cpp
index c4091f6..eef97b6 100644
--- a/engines/groovie/script.cpp
+++ b/engines/groovie/script.cpp
@@ -179,12 +179,20 @@ void Script::directGameLoad(int slot) {
 
 	// TODO: Return to the main script, likely reusing most of o_returnscript()
 
-	// HACK: We set variable 0x19 to the slot to load, and set the current
-	// instruction to the one that actually loads the saved game specified
-	// in that variable. This will change in other versions of the game and
-	// in other games.
-	setVariable(0x19, slot);
-	_currentInstruction = 0x287;
+	// HACK: We set the slot to load in the appropriate variable, and set the
+	// current instruction to the one that actually loads the saved game
+	// specified in that variable. This differs depending on the game and its
+	// version.
+	if (_version == kGroovieT7G) {
+		// 7th Guest
+		setVariable(0x19, slot);
+		_currentInstruction = 0x287;
+	} else {
+		// 11th Hour
+		setVariable(0xF, slot);
+		// FIXME: This bypasses a lot of the game's initialization procedure
+		_currentInstruction = 0xE78E;
+	}
 
 	// TODO: We'll probably need to start by running the beginning of the
 	// script to let it do the soundcard initialization and then do the






More information about the Scummvm-git-logs mailing list